@@ -21,10 +21,9 @@
 #include "btbrowsertest.h"
 #include "btparser.h"
 
-
-#include <QtTestWidgets>
-#include <QTemporaryFile>
 #include <QFileInfo>
+#include <QTemporaryFile>
+#include <QtTestWidgets>
 
 QTEST_MAIN(KateBtBrowserTest)
 
@@ -45,7 +44,6 @@ void KateBtBrowserTest::testParser()
     // 3) #41 0x0805e690 in ?? ()
     // 4) #5  0xffffe410 in __kernel_vsyscall ()
 
-
     QString bt = QStringLiteral("#24 0xb688ff8e in QApplication::notify (this=0xbf997e8c, receiver=0x82607e8, e=0xbf997074) at kernel/qapplication.cpp:3115");
     QList<BtInfo> info = KateBtParser::parseBacktrace(bt);
 
@@ -93,7 +91,7 @@ void KateBtBrowserTest::testParser()
 
     bt = QStringLiteral("    Thread 1 (Thread 0x7fb6ba260780 (LWP 16447)):\n[KCrash Handler]");
     info = KateBtParser::parseBacktrace(bt);
-    QVERIFY(info.size() == 0);
+    QVERIFY(info.empty());
 }
 
 // kate: space-indent on; indent-width 4; replace-tabs on;
