@@ -22,10 +22,10 @@
 class SQLManager;
 class QMouseEvent;
 
+#include <QSqlDriver>
+#include <QString>
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
-#include <qsqldriver.h>
-#include <qstring.h>
 
 class SchemaWidget : public QTreeWidget
 {
