@@ -20,8 +20,8 @@
 
 #include "kateprojectcodeanalysistoolflake8.h"
 
+#include <KLocalizedString>
 #include <QRegularExpression>
-#include <klocalizedstring.h>
 
 KateProjectCodeAnalysisToolFlake8::KateProjectCodeAnalysisToolFlake8(QObject *parent)
     : KateProjectCodeAnalysisTool(parent)
