@@ -40,6 +40,8 @@ public:
 
     void generateList(const QString &folder, bool recursive, bool hidden, bool symlinks, bool binary, const QString &types, const QString &excludes);
 
+    void terminateSearch();
+
     QStringList fileList();
 
 public Q_SLOTS:
@@ -47,6 +49,7 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void searching(const QString &path);
+    void fileListReady();
 
 private:
     void checkNextItem(const QFileInfo &item);
@@ -54,12 +57,12 @@ private:
 private:
     QString m_folder;
     QStringList m_files;
-    bool m_cancelSearch;
+    bool m_cancelSearch = false;
 
-    bool m_recursive;
-    bool m_hidden;
-    bool m_symlinks;
-    bool m_binary;
+    bool m_recursive = false;
+    bool m_hidden = false;
+    bool m_symlinks = false;
+    bool m_binary = false;
     QStringList m_types;
     QVector<QRegExp> m_excludeList;
     QElapsedTimer m_time;
