@@ -22,23 +22,23 @@
 #include <ktexteditor/editor.h>
 #include <ktexteditor/message.h>
 
+#include <KLineEdit>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KProcess>
 #include <QAction>
 #include <QDialog>
-#include <klineedit.h>
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
-#include <kprocess.h>
-#include <qstring.h>
+#include <QString>
 
+#include <KActionCollection>
 #include <KAuthorized>
 #include <KConfigGroup>
 #include <KPluginFactory>
 #include <KSharedConfig>
 #include <KXMLGUIFactory>
-#include <kactioncollection.h>
 
-#include <qapplication.h>
-#include <qclipboard.h>
+#include <QApplication>
+#include <QClipboard>
 
 K_PLUGIN_FACTORY_WITH_JSON(TextFilterPluginFactory, "textfilterplugin.json", registerPlugin<PluginKateTextFilter>();)
 
