@@ -22,11 +22,11 @@
 
 #include "pseudo_dtd.h"
 
+#include <QRegExp>
 #include <qdom.h>
-#include <qregexp.h>
 
-#include <klocalizedstring.h>
-#include <kmessagebox.h>
+#include <KLocalizedString>
+#include <KMessageBox>
 
 PseudoDTD::PseudoDTD()
 {
